/*
	basicConsumer - tutorial1 - Creating a basic barebones ETA consumer application

	The goal of this tutorial is to setup a Visual Studio project which defines the required compiler and linker options
	to successfully build and run.  The tutorial will simply setup the shell which enables us to perform the basic
	ETA initialization. This tutorial is the first part of a series of tutorials with the goal of creating a basic consumer 
	application.

	The series includes the following:

		o Tutorial 1 - Creating a basic barebones ETA consumer application
		o Tutorial 2 - Establishing a connection to an OMM-based data Provider
		o Tutorial 3 - Establishing a session with an OMM-based data Provider
		o Tutorial 4 - Retrieving level 1 content and decoding the results
		o Tutorial 5 - Retrieving level 2 content and decoding the results
 */

/* System headers */
#include <stdlib.h>

/* Application headers */
#include "basicConsumer.h"
/* ETA headers */
#include "rtr/rsslReactor.h"

/* Local functions */
void init();
void cleanUpAndExit(int code);
void exitApp(int code);


/*** MAIN ***/
int main(int argc, char **argv)
{
	// Initialization
	init();

	// Exit
	cleanUpAndExit(0);
}

/* Initialize RSSL and setup the main communication protocol details as outlined in the 3 steps within the introduction */
void init()
{
	RsslError error;

	/* Initialize RSSL. The locking mode RSSL_LOCK_GLOBAL_AND_CHANNEL is required to use the RsslReactor. */
	/* RsslReactor internally utilizes multiple threads */
	if (rsslInitialize(RSSL_LOCK_GLOBAL_AND_CHANNEL, &error) != RSSL_RET_SUCCESS)
	{
		printf("rsslInitialize(): failed <%s>\n", error.text);
		exit(RSSL_RET_FAILURE);
	}
}

/*
* Cleans up and exits the application.
*/
void cleanUpAndExit(int code)
{
	rsslUninitialize();

	exitApp(code);
}

void exitApp(int code)
{
	printf("Exiting.\n");
	exit(code);
}
